=========================
Google APIs common protos
=========================

googleapis-common-protos contains the python classes generated from the common
protos in the googleapis repository.

.. _`googleapis/googleapis`: https://github.com/googleapis/api-common-protos
